in highp vec4 var_position;
in highp vec3 var_normal;
in highp vec3 var_light_position;
in highp vec3 var_camera_position;
in highp vec4 var_shadowmapcoord0;

uniform highp vec4 tint;
uniform highp sampler2D tex_depth;

out highp vec4 frag_color;

float get_shadow()
{
    vec3 pos = var_shadowmapcoord0.xyz / var_shadowmapcoord0.w;
    vec2 pixel_size = 1.0 / vec2(textureSize(tex_depth, 0));

    float shadow = 0.0;
    float c = 0.0;
    int samples = 2;

    for (int x = -samples; x <= samples; ++x) {
        for (int y = -samples; y <= samples; ++y) {
            float depth = texture(tex_depth, pos.xy + vec2(x, y) * pixel_size).r;

            shadow += step(pos.z - 0.0035, depth);

            c += 1.0;
        }
    }

    return shadow / c;
}

void main()
{
    vec3 color = tint.xyz * tint.w;

    vec3 light_direction = normalize(var_position.xyz - var_light_position);
    vec3 normal = normalize(var_normal);

    float self_shadowing = dot(normal, -light_direction);

    float ambient = 1.0;
    float diffuse = clamp(max(length(min(get_shadow(), self_shadowing) * 0.5 + 0.5), 0.0), 0.0, 1.0);

    float intensity = ambient * 0.7 + diffuse * 0.3;

    frag_color = vec4(intensity * color, 1.0);
}
